pub struct ModpkgExtractor<'modpkg, TSource: Read + Seek> { /* private fields */ }Expand description
Extractor for ModPkg archives.
This struct provides functionality to extract chunks from a ModPkg archive to a specified directory, organized by layers.
Implementations
Sourceimpl<'modpkg, TSource: Read + Seek> ModpkgExtractor<'modpkg, TSource>
impl<'modpkg, TSource: Read + Seek> ModpkgExtractor<'modpkg, TSource>
Sourcepub fn new(modpkg: &'modpkg mut Modpkg<TSource>) -> Self
pub fn new(modpkg: &'modpkg mut Modpkg<TSource>) -> Self
Create a new extractor for the given ModPkg.
Sourcepub fn extract_all(
&mut self,
output_dir: impl AsRef<Path>,
) -> Result<(), ModpkgError>
pub fn extract_all( &mut self, output_dir: impl AsRef<Path>, ) -> Result<(), ModpkgError>
Extract all chunks from the ModPkg to the specified output directory.
Chunks will be organized by layer, with each layer having its own subdirectory.